@@ -1,5 +1,5 @@
-#ifndef WIN32
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
 #endif
 
 #include "ConversionManager.h"
