@@ -335,7 +335,13 @@ public:
   /// @}
 
   // Module management functions
-  void RegisterFactory(CModuleFactory *pFactory);
+  CDasherModule *RegisterModule(CDasherModule *pModule);
+  CDasherModule *GetModule(ModuleID_t iID);
+  CDasherModule *GetModuleByName(const std::string &strName);
+  CDasherModule *GetDefaultInputDevice();
+  CDasherModule *GetDefaultInputMethod();
+  void SetDefaultInputDevice(CDasherModule *);
+  void SetDefaultInputMethod(CDasherModule *);
 
   void StartShutdown();
 
@@ -428,9 +434,6 @@ protected:
 
   /// @}
 
-  CDasherModule *GetModule(ModuleID_t iID);
-  CDasherModule *GetModuleByName(const std::string &strName);
-
   CEventHandler *m_pEventHandler;
   CSettingsStore *m_pSettingsStore;
 
@@ -507,9 +510,9 @@ protected:
   virtual void ShutdownTimer() = 0;
 
   ///
-  /// Append text to the trainign file - used to store state between
+  /// Append text to the training file - used to store state between
   /// sessions
-  /// @todo Pass file path to the fuction rather than having implementations work it out themselves
+  /// @todo Pass file path to the function rather than having implementations work it out themselves
   ///
   
   virtual void WriteTrainFile(const std::string &strNewText) {
@@ -584,12 +587,12 @@ protected:
   CDasherScreen *m_DasherScreen;
   CDasherView *m_pDasherView;
   CDasherInput *m_pInput;
+  CInputFilter* m_pInputFilter;
+  CModuleManager m_oModuleManager;
   CAlphIO *m_AlphIO;
   CColourIO *m_ColourIO;
   CNodeCreationManager *m_pNCManager;
   CUserLogBase *m_pUserLog; 
-  CInputFilter* m_pInputFilter;
-  CModuleManager m_oModuleManager;
   //  CTrainingHelper *m_pTrainingHelper;
   /// @}
 
