@@ -1,6 +1,6 @@
 // DasherViewSquare.cpp
 //
-// Copyright (c) 2007 The Dasher Team
+// Copyright (c) 2008 The Dasher Team
 //
 // This file is part of Dasher.
 //
@@ -34,9 +34,9 @@
 #include "View/DelayedDraw.h"
 
 #include <algorithm>
-#include <limits>
-
 #include <iostream>
+#include <limits>
+#include <stdlib.h>
 
 using namespace Dasher;
 
@@ -50,8 +50,6 @@ static char THIS_FILE[] = __FILE__;
 #endif
 #endif
 
-static bool g_bDebug = false;
-
 // FIXME - quite a lot of the code here probably should be moved to
 // the parent class (DasherView). I think we really should make the
 // parent class less general - we're probably not going to implement
@@ -139,7 +137,7 @@ void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iR
   //if(iScreenRight > Screen()->GetWidth()) 
   //  iScreenRight=Screen()->GetWidth();
 
-  // Blank the regoin around the root node:
+  // Blank the region around the root node:
   
   if(iRootMin > iDasherMinY)
     DasherDrawRectangle(iDasherMaxX, iDasherMinY, iDasherMinX, iRootMin, 0, 0, Nodes1, false,true, 1);
@@ -806,27 +804,33 @@ void CDasherViewSquare::GetScaleFactor( int eOrientation, myint *iScaleFactorX,
 
 inline myint CDasherViewSquare::CustomIDiv(myint iNumerator, myint iDenominator) { 
   // Integer division rounding away from zero
-  
-#ifdef _WIN32
-  myint quot = iNumerator / iDenominator;
-  myint rem = (int64)iNumerator % (int64)iDenominator;
 
-  if(rem < 0)
-    return quot - 1;
-  else if (rem > 0)
-    return quot + 1;
-  else
-    return quot;
+  long long int num, denom, quot, rem;
+  myint res;
+
+  num   = iNumerator;
+  denom = iDenominator;
+
+  DASHER_ASSERT(denom != 0);
+
+#ifdef HAVE_LLDIV
+  lldiv_t ans = ::lldiv(num, denom);
+
+  quot = ans.quot;
+  rem  = ans.rem;
 #else
-  lldiv_t res = __gnu_cxx::lldiv(iNumerator, iDenominator);
-  
-  if(res.rem < 0)
-    return res.quot - 1;
-  else if (res.rem > 0)
-    return res.quot + 1;
-  else
-    return res.quot;
+  quot = num / denom;
+  rem  = num % denom;
 #endif
+  
+  if (rem < 0)
+    res = quot - 1;
+  else if (rem > 0)
+    res = quot + 1;
+  else
+    res = quot;
+
+  return res;
 
   // return (iNumerator + iDenominator - 1) / iDenominator;
 }
