@@ -20,7 +20,12 @@ CNodeCreationManager::CNodeCreationManager(Dasher::CDasherInterfaceBase *pInterf
   
   m_pLanguageModel = m_pAlphabetManagerFactory->GetLanguageModel();
   m_pAlphabet = m_pAlphabetManagerFactory->GetAlphabet();
- 
+
+  // Train the language model
+  CTrainer *pTrainer =  m_pAlphabetManagerFactory->GetTrainer();
+  m_pAlphabet->Train(GetStringParameter(SP_USER_LOC), GetStringParameter(SP_SYSTEM_LOC), pTrainer);
+  delete pTrainer;
+
   int iConversionID(m_pAlphabetManagerFactory->GetConversionID());
 
 #ifndef _WIN32_WCE
@@ -149,6 +154,15 @@ void CNodeCreationManager::EnterText(CLanguageModel::Context context, std::strin
     m_pLanguageModel->EnterSymbol(context, Symbols[i]); // FIXME - conversion to symbol alphabet
 }
 
-CAlphabetManagerFactory::CTrainer *CNodeCreationManager::GetTrainer() {
-  return m_pAlphabetManagerFactory->GetTrainer();
+void 
+CNodeCreationManager::ImportTrainingText(const std::string &strPath) {
+  CTrainer *pTrainer = NULL;
+
+  if(m_pAlphabetManagerFactory)
+    pTrainer = m_pAlphabetManagerFactory->GetTrainer();
+
+  if(m_pAlphabet && pTrainer)
+    m_pAlphabet->Train(strPath, pTrainer);
+
+  delete pTrainer;
 }
