@@ -4,13 +4,15 @@
 //
 // Linux-specific subclass of SocketInputBase: provides network socket control of Dasher cursor
 
+#include "../Common/Common.h"
+
 #include "SocketInput.h"
 #include "SocketInputBase.h"
 
 #include <pthread.h>
 #include <libintl.h>
 
-#define _(_x) gettext(_x)
+#include "../Common/I18n.h"
 
 using namespace Dasher;
 
