@@ -1,4 +1,6 @@
-#include "../../config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <glib/gi18n.h>
 #include <libintl.h>
@@ -22,7 +24,7 @@ typedef struct _BoolTranslation BoolTranslation;
 
 struct _BoolTranslation {
   gint iParameter;
-  gchar *szWidgetName;
+  const gchar *szWidgetName;
   GtkWidget *pWidget;
 };
 
@@ -54,9 +56,9 @@ typedef struct _StringTranslation StringTranslation;
 
 struct _StringTranslation {
   gint iParameter;
-  gchar *szWidgetName;
+  const gchar *szWidgetName;
   GtkWidget *pWidget;
-  gchar *szHelperName;
+  const gchar *szHelperName;
   GtkWidget *pHelper;
 };
 
@@ -130,7 +132,7 @@ static void dasher_preferences_dialogue_populate_list(DasherPreferencesDialogue
 static void dasher_preferences_dialogue_update_special(DasherPreferencesDialogue *pSelf, int iID);
 static void dasher_preferences_dialogue_refresh_parameter(DasherPreferencesDialogue *pSelf, GtkWidget *pWidget, gpointer pUserData);
 
-/* Special privalte members called via table (see below) */
+/* Special private members called via table (see below) */
 static void dasher_preferences_dialogue_populate_special_speed(DasherPreferencesDialogue *pSelf);
 static void dasher_preferences_dialogue_populate_special_mouse_start(DasherPreferencesDialogue *pSelf);
 static void dasher_preferences_dialogue_populate_special_orientation(DasherPreferencesDialogue *pSelf);
@@ -335,7 +337,7 @@ extern "C" gboolean dasher_preferences_refresh_foreach_function(GtkTreeModel *pM
   gtk_tree_model_get(pModel, pIter, 2, &szComparison, -1);
 
   if(!strcmp(szTarget, szComparison)) {
-    free(szComparison);
+    g_free(szComparison);
     // Todo: set selection here?
     gtk_tree_view_set_cursor((GtkTreeView *)pPointers[1], pPath, NULL, false);
 
@@ -344,7 +346,7 @@ extern "C" gboolean dasher_preferences_refresh_foreach_function(GtkTreeModel *pM
     return true;
   }
 
-  free(szComparison);
+  g_free(szComparison);
   
   return false;
 }
@@ -488,7 +490,7 @@ extern "C" void on_list_selection(GtkTreeSelection *pSelection, gpointer pUserDa
     gtk_tree_model_get(pModel, &oIter, 0, &iParameter, 1, &pHelper, 2, &szValue, 4, &pHelperWindow, 5, &pHelperWindowRef, -1);
     
     dasher_app_settings_set_string(pPrivate->pAppSettings, iParameter, szValue);
-    free(szValue);
+    g_free(szValue);
 
     if(pHelper) {
       gtk_widget_set_sensitive(GTK_WIDGET(pHelper), pHelperWindow != NULL);
