@@ -1,4 +1,6 @@
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include "dasher_action_keyboard.h"
 #include "dasher_editor.h"
 
@@ -57,5 +59,5 @@ dasher_action_keyboard_execute(DasherAction *pSelf, DasherEditor *pEditor, int i
 
 static const gchar *
 dasher_action_keyboard_get_name(DasherAction *pSelf) {
-  return "Enter Text";
+  return _("Enter Text");
 }
