@@ -1,5 +1,7 @@
 // TODO: Make inclusion in build system conditional
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #ifdef GNOME_SPEECH
 
 #include "dasher_action_speech.h"
@@ -8,6 +10,7 @@
 #include <glib/gi18n.h>
 #include <gnome-speech/gnome-speech.h>
 #include <libbonobo.h>
+#include <cstring>
 //#include <libintl.h>
 //#include <string.h>
 
@@ -28,8 +31,8 @@ typedef struct _DasherActionSpeechPrivate DasherActionSpeechPrivate;
 
 G_DEFINE_TYPE(DasherActionSpeech, dasher_action_speech, TYPE_DASHER_ACTION);
 
-static gboolean dasher_action_speech_execute(DasherAction *pSelf, DasherEditorInternal *pEditor, int iIdx);
-static gboolean dasher_action_speech_preview(DasherAction *pSelf, DasherEditorInternal *pEditor);
+static gboolean dasher_action_speech_execute(DasherAction *pSelf, DasherEditor *pEditor, int iIdx);
+static gboolean dasher_action_speech_preview(DasherAction *pSelf, DasherEditor *pEditor);
 static const gchar *dasher_action_speech_get_name(DasherAction *pSelf);
 static int dasher_action_speech_get_sub_count(DasherAction *pSelf);
 static const gchar *dasher_action_speech_get_sub_name(DasherAction *pSelf, int iIdx);
@@ -66,17 +69,17 @@ dasher_action_speech_new() {
 }
 
 static gboolean 
-dasher_action_speech_execute(DasherAction *pSelf, DasherEditorInternal *pEditor, int iIdx) {
+dasher_action_speech_execute(DasherAction *pSelf, DasherEditor *pEditor, int iIdx) {
   DasherActionSpeechPrivate *pDasherActionSpeechPrivate = DASHER_ACTION_SPEECH_GET_PRIVATE(pSelf);
 
   const char *szData;
 
   switch(iIdx) {
   case 0:
-    szData = dasher_editor_internal_get_all_text(pEditor);
+    szData = dasher_editor_get_all_text(pEditor);
     break;
   case 1:
-    szData = dasher_editor_internal_get_new_text(pEditor);
+    szData = dasher_editor_get_new_text(pEditor);
     break;
   case 2:
     szData = pDasherActionSpeechPrivate->szLast;
@@ -107,13 +110,13 @@ dasher_action_speech_execute(DasherAction *pSelf, DasherEditorInternal *pEditor,
 }
 
 static gboolean 
-dasher_action_speech_preview(DasherAction *pSelf, DasherEditorInternal *pEditor) {
-  const gchar *szData = dasher_editor_internal_get_all_text(pEditor);
+dasher_action_speech_preview(DasherAction *pSelf, DasherEditor *pEditor) {
+  const gchar *szData = dasher_editor_get_all_text(pEditor);
 
   if(!szData)
     return false;
 
-  gchar *szWord = strrchr(szData, ' ') + 1;
+  const gchar *szWord = strrchr(szData, ' ') + 1;
 
   DasherActionSpeechPrivate *pDasherActionSpeechPrivate = DASHER_ACTION_SPEECH_GET_PRIVATE(pSelf);
   
@@ -138,10 +141,13 @@ static const gchar *
 dasher_action_speech_get_sub_name(DasherAction *pSelf, int iIdx) {
   switch(iIdx) {
   case 0:
+    /* TRANSLATORS: Send all text to the text-to-speech engine. */
     return _("All");
   case 1:
+    /* TRANSLATORS: Send most recently entered text to the text-to-speech engine. */
     return _("Last");
   case 2:
+    /* TRANSLATORS: Repeat the last phrase sent to the text-to-speech engine. */
     return _("Repeat");
   default:
     return NULL;
