@@ -1,4 +1,8 @@
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <cstring>
 
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
@@ -8,7 +12,10 @@
 #ifdef WITH_MAEMOFULLSCREEN
 #include <hildon-widgets/hildon-program.h>
 #endif
+#ifdef GNOME_LIBS
 #include <libgnome/libgnome.h>
+#endif
+#include <unistd.h>
 
 #include "GtkDasherControl.h"
 #include "KeyboardHelper.h"
@@ -31,8 +38,8 @@ static DasherMain *g_pDasherMain = NULL;
 static gboolean g_bSend = true;
 
 struct _DasherMainPrivate {
-  // The glade XML file - TODO: this shouldn't be kept after interface has been loaded
   GladeXML *pGladeXML;
+  GladeXML *pPrefXML;
 
   // Child objects owned here
   DasherAppSettings *pAppSettings;
@@ -132,7 +139,7 @@ static void dasher_main_setup_window_state(DasherMain *pSelf);
 static void dasher_main_setup_window_style(DasherMain *pSelf);
 static void dasher_main_setup_internal_layout(DasherMain *pSelf);
 //static void dasher_main_refresh_font(DasherMain *pSelf);
-static void dasher_main_set_filename(DasherMain *pSelf);
+static void dasher_main_set_window_title(DasherMain *pSelf);
 
 /* ... Table based menu/toolbar commands */
 static void dasher_main_connect_menus(DasherMain *pSelf);
@@ -152,6 +159,7 @@ static void dasher_main_alphabet_combo_changed(DasherMain *pSelf);
 static void dasher_main_populate_alphabet_combo(DasherMain *pSelf);
 
 /* TODO: order these in file */
+static GladeXML *dasher_main_open_glade_xml(const char *szGladeFilename);
 static void dasher_main_load_interface(DasherMain *pSelf);
 static void dasher_main_create_preferences(DasherMain *pSelf);
 static void dasher_main_handle_parameter_change(DasherMain *pSelf, int iParameter);
@@ -174,7 +182,7 @@ extern "C" GtkWidget *create_dasher_editor(gchar *szName, gchar *szString1, gcha
 
 /* ... Message handling from main window widgets */
 extern "C" gboolean dasher_main_cb_menu_command(GtkWidget *pWidget, gpointer pUserData);
-extern "C" gboolean speed_changed(GtkWidget *pWidget, gpointer user_data);
+extern "C" void speed_changed(GtkWidget *pWidget, gpointer user_data);
 extern "C" void alphabet_combo_changed(GtkWidget *pWidget, gpointer pUserData);
 extern "C" void dasher_main_cb_filename_changed(DasherEditor *pEditor, gpointer pUserData);
 extern "C" void dasher_main_cb_buffer_changed(DasherEditor *pEditor, gpointer pUserData);
@@ -246,7 +254,7 @@ dasher_main_finalize(GObject *pObject) {
 
   gtk_widget_destroy(pPrivate->pMainWindow);
 
-  /* TDO: Do we need to take down anything else? */
+  /* TODO: Do we need to take down anything else? */
 }
 
 /* Public methods */
@@ -266,24 +274,25 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
     /* Load the user interface from the glade file */
     if(pCommandLine && pCommandLine->szAppStyle) {
       if(!strcmp(pCommandLine->szAppStyle, "traditional")) {
-	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 0);
+	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, APP_STYLE_TRAD);
       }
       else if(!strcmp(pCommandLine->szAppStyle, "compose")) {
-	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 1);
+	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, APP_STYLE_COMPOSE);
       }
       else if(!strcmp(pCommandLine->szAppStyle, "direct")) {
-	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 2);
+	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, APP_STYLE_DIRECT);
       }
       else if(!strcmp(pCommandLine->szAppStyle, "fullscreen")) {
-	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 3);
+	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, APP_STYLE_FULLSCREEN);
       }
       else {
-	g_error("Application style %s is not supported", pCommandLine->szAppStyle);
+        g_critical("Application style %s is not supported", pCommandLine->szAppStyle);
+        return 0;
       }
     }
     else { 
-      // Direct entry is now the default
-      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 2);
+      // By default use traditional mode
+      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, APP_STYLE_TRAD);
     }
 
     dasher_main_load_interface(pDasherMain);
@@ -300,6 +309,8 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
 
       while(*pszCurrent) {
 	gchar *szJoin = g_strrstr(*pszCurrent, "=");
+        // Note to translators: This message will be output for command line errors when the "=" in --options=foo is missing.
+        const gchar *errorMessage = _("option setting is missing \"=\".");
 
 	if(szJoin) {
 	  int iLength = szJoin - *pszCurrent;
@@ -308,12 +319,15 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
 	  memcpy(szKey, *pszCurrent, iLength);
 	  szKey[iLength] = '\0';
 	  
-	  dasher_app_settings_cl_set(pPrivate->pAppSettings, szKey, szJoin + 1);
+	  errorMessage = dasher_app_settings_cl_set(pPrivate->pAppSettings, szKey, szJoin + 1);
 	  
 	  g_free(szKey);
 	}
-	else {
-	  g_error("Invalid option string specified");
+        
+	if (errorMessage) {
+          // Note to translators: This string will be output when --options= specifies an unknown option.
+	  g_critical("%s: '%s', %s", _("Invalid option string specified"), *pszCurrent, errorMessage);
+          return 0;
 	}
 
 	++pszCurrent;
@@ -370,8 +384,14 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
     dasher_lock_dialogue_new(pPrivate->pGladeXML, 0);
 #endif
 
+    g_object_unref(pPrivate->pGladeXML);
+    pPrivate->pGladeXML = 0;
+
+    g_object_unref(pPrivate->pPrefXML);
+    pPrivate->pPrefXML = 0;
+
     /* Set up various bits and pieces */
-    dasher_main_set_filename(pDasherMain);
+    dasher_main_set_window_title(pDasherMain);
     dasher_main_populate_controls(pDasherMain);
     dasher_main_connect_control(pDasherMain);
 
@@ -381,12 +401,28 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
   }
 }
 
+static GladeXML *
+dasher_main_open_glade_xml(const char *szGladeFilename) {
+  g_message("Opening Glade file: %s", szGladeFilename);
+
+  GladeXML *xml = glade_xml_new(szGladeFilename, NULL, NULL);
+
+  if (!xml) {
+    g_error("Can't find Glade file: %s. Dasher is unlikely to be correctly installed.", szGladeFilename);
+  }
+
+  glade_xml_signal_autoconnect(xml);
+  
+  return xml;
+}
+
 /* Load the window interface from the glade file, and do various initialisation bits and pieces */
 static void 
 dasher_main_load_interface(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
   
   const char *szGladeFilename = NULL;
+  const char *szPrefGladeFilename = NULL;
 
 #ifdef WITH_GPE
   szGladeFilename = PROGDATA "/dashergpe.glade";
@@ -398,37 +434,44 @@ dasher_main_load_interface(DasherMain *pSelf) {
   //szGladeFilename = "/var/lib/install" PROGDATA "/dashermaemo.glade";
   szGladeFilename = PROGDATA "/dashermaemo.glade";
 #endif
+  szPrefGladeFilename = PROGDATA "/dashermaemo.preferences.glade";
 #else
   switch(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE)) {
-  case 0:
+  case APP_STYLE_TRAD:
     szGladeFilename = PROGDATA "/dasher.traditional.glade";
     break;
-  case 1:
+  case APP_STYLE_COMPOSE:
     szGladeFilename = PROGDATA "/dasher.compose.glade";
     break;
-  case 2:
-    //    szGladeFilename = PROGDATA "/dasher.direct.glade";
-    szGladeFilename = PROGDATA "/dasher.traditional.glade";
+  case APP_STYLE_DIRECT:
+    szGladeFilename = PROGDATA "/dasher.direct.glade";
     break;
-  case 3:
+  case APP_STYLE_FULLSCREEN:
     szGladeFilename = PROGDATA "/dasher.fullscreen.glade";
     break;
   default:
     g_error("Inconsistent application style specified.");
   }
+  szPrefGladeFilename = PROGDATA "/dasher.preferences.glade";
 #endif
 
   if(!szGladeFilename) {
     g_error("Failure to determine glade filename");
   }
 
-  pPrivate->pGladeXML = glade_xml_new(szGladeFilename, NULL, NULL);
+  pPrivate->pGladeXML = dasher_main_open_glade_xml(szGladeFilename);
 
-  if (!pPrivate->pGladeXML) {
-    g_error("Can't find Glade file: %s. Dasher is unlikely to be correctly installed.", szGladeFilename);
+  if (szPrefGladeFilename) {
+    pPrivate->pPrefXML = dasher_main_open_glade_xml(szPrefGladeFilename);
+  }
+  else {
+    // If no separate preference file, preferences widget is in main glade xml
+    pPrivate->pPrefXML = (GladeXML *) g_object_ref(pPrivate->pGladeXML);
   }
 
-  glade_xml_signal_autoconnect(pPrivate->pGladeXML);
+  // XXX PRLW: Hide the Help Contents as there is no handler to display help.
+  // #575365
+  gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "menu_command_help"));
 
   // Save the details of some of the widgets for later
   //  pPrivate->pActionPane = glade_xml_get_widget(pPrivate->pGladeXML, "vbox39");
@@ -497,16 +540,16 @@ dasher_main_load_interface(DasherMain *pSelf) {
   g_object_ref(options_menu);
   g_object_ref(help_menu);
 
-  gtk_menu_item_remove_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem4")));
-  gtk_menu_item_remove_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "options1")));
-  gtk_menu_item_remove_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem7")));
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem4")), NULL);
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "options1")), NULL);
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem7")), NULL);
 
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(file_menu_item),file_menu);
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(options_menu_item),options_menu); 
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(help_menu_item),help_menu);
-  gtk_menu_append(main_menu, file_menu_item);
-  gtk_menu_append(main_menu, options_menu_item);
-  gtk_menu_append(main_menu, help_menu_item);
+  gtk_menu_shell_append((GtkMenuShell *)main_menu, file_menu_item);
+  gtk_menu_shell_append((GtkMenuShell *)main_menu, options_menu_item);
+  gtk_menu_shell_append((GtkMenuShell *)main_menu, help_menu_item); 
 
   g_object_unref(file_menu);
   g_object_unref(options_menu);
@@ -559,7 +602,7 @@ dasher_main_load_interface(DasherMain *pSelf) {
   
   // Hide any widgets which aren't appropriate for this mode
   
-  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == 2) {
+  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == APP_STYLE_DIRECT) {
     gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "dasher_menu_bar"));
       
     gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_new"));
@@ -585,7 +628,7 @@ dasher_main_load_interface(DasherMain *pSelf) {
 static void 
 dasher_main_create_preferences(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
-  pPrivate->pPreferencesDialogue = dasher_preferences_dialogue_new(pPrivate->pGladeXML, pPrivate->pEditor, pPrivate->pAppSettings, GTK_WINDOW(pPrivate->pMainWindow));
+  pPrivate->pPreferencesDialogue = dasher_preferences_dialogue_new(pPrivate->pPrefXML, pPrivate->pEditor, pPrivate->pAppSettings, GTK_WINDOW(pPrivate->pMainWindow));
 }
 
 // DasherEditor *
@@ -668,7 +711,7 @@ dasher_main_load_state(DasherMain *pSelf) {
   int iWindowHeight;
   int iEditHeight;
   
-  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) != 1) {
+  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) != APP_STYLE_COMPOSE) {
     iEditHeight = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_EDIT_HEIGHT);
     iWindowWidth = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_SCREEN_WIDTH);
     iWindowHeight = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_SCREEN_HEIGHT);
@@ -715,8 +758,10 @@ dasher_main_save_state(DasherMain *pSelf) {
    gtk_window_get_size(GTK_WINDOW(pPrivate->pMainWindow), &iWindowWidth, &iWindowHeight);
    iEditHeight = gtk_paned_get_position(GTK_PANED(pPrivate->pDivider));
 
-   if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) != 1) {
-     dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_EDIT_HEIGHT, iEditHeight);
+   if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) != APP_STYLE_COMPOSE) {
+     // APP_STYLE_DIRECT doesn't have an edit window.
+     if (dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) != APP_STYLE_DIRECT)
+       dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_EDIT_HEIGHT, iEditHeight);
      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_SCREEN_WIDTH, iWindowWidth);
      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_SCREEN_HEIGHT, iWindowHeight);
    }
@@ -886,13 +931,13 @@ dasher_main_setup_window_style(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
   switch(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE)) {
-  case 0:
+  case APP_STYLE_TRAD:
     // Nothing to do
     break;
-  case 1:
+  case APP_STYLE_COMPOSE:
     // Nothing to do
     break;
-  case 2:
+  case APP_STYLE_DIRECT:
     // Direct mode - set always on top
     gtk_window_set_keep_above(GTK_WINDOW(pPrivate->pMainWindow), true);
 
@@ -902,7 +947,7 @@ dasher_main_setup_window_style(DasherMain *pSelf) {
     // Stick on all desktops
     gtk_window_stick(GTK_WINDOW(pPrivate->pMainWindow));
     break;
-  case 3:
+  case APP_STYLE_FULLSCREEN:
     // Fullscreen mode - set fullscreen
     gtk_window_fullscreen(GTK_WINDOW(pPrivate->pMainWindow));
     break;
@@ -943,17 +988,21 @@ dasher_main_setup_internal_layout(DasherMain *pSelf) {
 
 // TODO: Fold into setup controls?
 static void 
-dasher_main_set_filename(DasherMain *pSelf) {
+dasher_main_set_window_title(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
   const gchar *szFilename = dasher_editor_get_filename(pPrivate->pEditor);
 
+  // Note to translators: This is the name of the dasher program as it appears
+  // in a window title.
+  gchar * dasher = _("Dasher");
   if(szFilename == 0) {
-    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), "Dasher");
+    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), dasher);
   }
   else {
-    // TODO: Prepend 'Dasher - ' to filename?
-    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), szFilename);
+    gchar *title = g_strdup_printf("%s - %s", dasher, szFilename);
+    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), title);
+    g_free (title);
   }
 }
 
@@ -962,7 +1011,7 @@ dasher_main_connect_menus(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
   int iNumItems = sizeof(MenuCommands) / sizeof(DasherMenuCommand);
-
+  
   for(int i(0); i < iNumItems; ++i) {
     GtkWidget *pWidget;
 
@@ -977,6 +1026,7 @@ dasher_main_connect_menus(DasherMain *pSelf) {
       else
 	g_signal_connect(G_OBJECT(pWidget), "clicked", G_CALLBACK(dasher_main_cb_menu_command), pSelf);
   }
+  
 }
 
 static void 
@@ -1028,6 +1078,8 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
   GtkWidget *pDialogue = NULL;
 
   if(dasher_editor_file_changed(pPrivate->pEditor)) {
+// XXX PRLW: Just open the save dialogue box.
+#if 0
     const gchar *szFilename = dasher_editor_get_filename(pPrivate->pEditor);
 
     if(szFilename) {
@@ -1037,10 +1089,13 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
 					 szFilename);
     }
     else {
+#endif
       pDialogue = gtk_message_dialog_new(GTK_WINDOW(pPrivate->pMainWindow), GTK_DIALOG_MODAL, 
 					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, 
 					 _("Do you want to save your changes?\n\nYour changes will be lost if you don't save them."));
+#if 0
     }
+#endif
 
     gtk_dialog_add_buttons(GTK_DIALOG(pDialogue), 
 			   _("Don't save"), GTK_RESPONSE_REJECT,
@@ -1050,27 +1105,34 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
 
     switch (gtk_dialog_run(GTK_DIALOG(pDialogue))) {
     case GTK_RESPONSE_REJECT:
-      //      write_to_file(); // FIXME - REIMPLEMENT
       gtk_main_quit();
       break;
     case GTK_RESPONSE_CANCEL:
       gtk_widget_destroy(GTK_WIDGET(pDialogue));
       break;
     case GTK_RESPONSE_ACCEPT:
-      gtk_widget_destroy(GTK_WIDGET(pDialogue));
-      //      write_to_file(); // FIXME - REIMPLEMENT
-      //      save_file_and_quit(NULL, NULL);
+      dasher_editor_command(pPrivate->pEditor, "save");
+      gtk_main_quit();
+      break;
     }
   }
   else {
-    // It should be noted that write_to_file merely saves the new text to the training
-    // file rather than saving it to a file of the user's choice
+	pDialogue = gtk_message_dialog_new(GTK_WINDOW(pPrivate->pMainWindow), GTK_DIALOG_MODAL, 
+					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, 
+					 _("Are you sure you wish to quit?"));
 
-    // FIXME - REIMPLEMENT
+    	gtk_dialog_add_buttons(GTK_DIALOG(pDialogue), 
+			   _("Don't quit"), GTK_RESPONSE_REJECT,
+			   _("Quit"), GTK_RESPONSE_ACCEPT, 
+			   NULL);
 
-    //    write_to_file();
-
-    gtk_main_quit();
+    switch (gtk_dialog_run(GTK_DIALOG(pDialogue))) {
+    case GTK_RESPONSE_REJECT:
+	gtk_widget_destroy(GTK_WIDGET(pDialogue));
+      break;
+    case GTK_RESPONSE_ACCEPT:
+      gtk_main_quit();
+    }
   }
 }
 
@@ -1110,19 +1172,22 @@ dasher_main_command_about(DasherMain *pSelf) {
   const gchar *authors[] = {
     "Chris Ball",
     "Ignas Budvytis",
+    "Peter Conlon",
     "Phil Cowans",
     "Frederik Eaton",
     "Behdad Esfahbod",
     "Matthew Garrett",
     "Chris Hack",
+    "Takashi Kaburagi",
+    "Sega Kazue",
+    "Alan Lawrence",
     "David MacKay",
     "Iain Murray",
-    "Sega Kazue",
-    "Takashi Kaburagi",
     "Martijn van Veen",
     "Keith Vertanen",
     "Hanna Wallach",
     "David Ward",
+    "Patrick Welche",
     "Brian Williams",
     "Seb Wills",
     "Will Zou",
@@ -1141,7 +1206,7 @@ dasher_main_command_about(DasherMain *pSelf) {
   gtk_show_about_dialog(GTK_WINDOW(pPrivate->pMainWindow),
 			"authors", authors,
 			"comments", _("Dasher is a predictive text entry application"), 
-			"copyright", "Copyright \xC2\xA9 1998-2007 The Dasher Project", 
+			"copyright", "Copyright \xC2\xA9 1998-2009 The Dasher Project", 
 			"documenters", documenters,
 			"license", "GPL 2+",
 			"logo-icon-name", "dasher",
@@ -1204,7 +1269,7 @@ static gboolean
 dasher_main_speed_changed(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
   
-  int iNewValue( static_cast<int>(round(gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(pPrivate->pSpeedBox)) * 100)));
+  int iNewValue( static_cast<int>(round(gtk_spin_button_get_value(GTK_SPIN_BUTTON(pPrivate->pSpeedBox)) * 100)));
   
   if(dasher_app_settings_get_long(pPrivate->pAppSettings, LP_MAX_BITRATE) != iNewValue)
     dasher_app_settings_set_long(pPrivate->pAppSettings, LP_MAX_BITRATE, iNewValue);
@@ -1218,18 +1283,20 @@ dasher_main_alphabet_combo_changed(DasherMain *pSelf) {
 
   GtkTreeIter sIter;
   
-  gtk_combo_box_get_active_iter(GTK_COMBO_BOX(pPrivate->pAlphabetCombo), &sIter);
+  if(gtk_combo_box_get_active_iter(GTK_COMBO_BOX(pPrivate->pAlphabetCombo), &sIter)) {
+    char *szSelected;
+    gtk_tree_model_get(GTK_TREE_MODEL(pPrivate->pAlphabetList), &sIter, 0, &szSelected, -1);
+    
+    if(!strcmp("More Alphabets...", szSelected)) {
+      gtk_combo_box_set_active(GTK_COMBO_BOX(pPrivate->pAlphabetCombo), 0);
+      //    dasher_preferences_dialogue_show(pPrivate->pPreferencesDialogue);
+      dasher_main_command(pSelf, "preferences_alphabet");
+    }
+    else 
+      dasher_app_settings_set_string(pPrivate->pAppSettings, SP_ALPHABET_ID, szSelected);
 
-  const char *szSelected;
-  gtk_tree_model_get(GTK_TREE_MODEL(pPrivate->pAlphabetList), &sIter, 0, &szSelected, -1);
-
-  if(!strcmp("More Alphabets...", szSelected)) {
-    gtk_combo_box_set_active(GTK_COMBO_BOX(pPrivate->pAlphabetCombo), 0);
-    //    dasher_preferences_dialogue_show(pPrivate->pPreferencesDialogue);
-    dasher_main_command(pSelf, "preferences_alphabet");
+    g_free(szSelected);
   }
-  else 
-    dasher_app_settings_set_string(pPrivate->pAppSettings, SP_ALPHABET_ID, szSelected);
 }
 
 static void 
@@ -1329,7 +1396,7 @@ create_dasher_editor(gchar *szName, gchar *szString1, gchar *szString2, gint iIn
   DasherMain *pDasherMain = DASHER_MAIN(g_pDasherMain);
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
 
-  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == 2)
+  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == APP_STYLE_DIRECT)
     return GTK_WIDGET(dasher_editor_external_new());
   else
     return GTK_WIDGET(dasher_editor_internal_new());
@@ -1342,13 +1409,10 @@ dasher_main_cb_menu_command(GtkWidget *pWidget, gpointer pUserData) {
   return FALSE; // TODO: Scheck semantics of return value
 }
 
-extern "C" gboolean 
+extern "C" void 
 speed_changed(GtkWidget *pWidget, gpointer user_data) {
   if(g_pDasherMain)
-    return dasher_main_speed_changed(g_pDasherMain);
-
-  // TODO: Check callback return functions
-  return false;
+    dasher_main_speed_changed(g_pDasherMain);
 }
 
 extern "C" void 
@@ -1360,7 +1424,7 @@ alphabet_combo_changed(GtkWidget *pWidget, gpointer pUserData) {
 extern "C" void 
 dasher_main_cb_filename_changed(DasherEditor *pEditor, gpointer pUserData) {
   if(g_pDasherMain)
-    dasher_main_set_filename(g_pDasherMain);
+    dasher_main_set_window_title(g_pDasherMain);
 }
 
 extern "C" void 
