@@ -11,10 +11,10 @@
 
 G_BEGIN_DECLS
 #define TYPE_GAME_MODE_HELPER         (game_mode_helper_get_type())
-#define GAME_MODE_HELPER(obj)         (GTK_CHECK_CAST((obj), TYPE_GAME_MODE_HELPER, GameModeHelper ))
-#define GAME_MODE_HELPER_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), TYPE_GAME_MODE_HELPER, GameModeHelper ))
-#define IS_GAME_MODE_HELPER(obj)		(GTK_CHECK_TYPE ((obj), TYPE_GAME_MODE_HELPER))
-#define IS_GAME_MODE_HELPER_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), TYPE_GAME_MODE_HELPER))
+#define GAME_MODE_HELPER(obj)         (G_TYPE_CHECK_INSTANCE_CAST((obj), TYPE_GAME_MODE_HELPER, GameModeHelper ))
+#define GAME_MODE_HELPER_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GAME_MODE_HELPER, GameModeHelper ))
+#define IS_GAME_MODE_HELPER(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GAME_MODE_HELPER))
+#define IS_GAME_MODE_HELPER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GAME_MODE_HELPER))
 
 typedef struct _GameModeHelper GameModeHelper;
 typedef struct _GameModeHelperClass GameModeHelperClass;
