@@ -35,13 +35,83 @@ static menuentry menutable[] = {
   {BP_PALETTE_CHANGE, IDC_COLOURSCHEME, true}
 };
 
-CAlphabetBox::CAlphabetBox(HWND Parent, CDasherInterfaceBase *DI)
-:m_pDasherInterface(DI), m_CurrentAlphabet(DI->GetStringParameter(SP_ALPHABET_ID)), m_CurrentColours(DI->GetStringParameter(SP_COLOUR_ID)), Editing(false), Cloning(false), EditChar(false), CustomBox(0), CurrentGroup(0), CurrentChar(0) {
+CAlphabetBox::CAlphabetBox(HWND Parent, CDasherInterfaceBase *DI, CAppSettings *pAppSettings)
+: CPrefsPageBase(Parent, DI, pAppSettings), m_pDasherInterface(DI), m_CurrentAlphabet(DI->GetStringParameter(SP_ALPHABET_ID)),  Editing(false), Cloning(false), EditChar(false), CustomBox(0), CurrentGroup(0), CurrentChar(0) {
   m_hwnd = 0;
   m_hPropertySheet = 0;
 }
 
 void CAlphabetBox::PopulateList() {
+#ifndef JAPANESE
+    EnableWindow(GetDlgItem(m_hwnd, IDC_LM_JAPANESE), FALSE);
+#endif
+
+    slider = GetDlgItem(m_hwnd, IDC_UNIFORMSLIDER);
+    SendMessage(slider, TBM_SETPAGESIZE, 0L, 20); // PgUp and PgDown change bitrate by reasonable amount
+    SendMessage(slider, TBM_SETTICFREQ, 10, 0L);
+    SendMessage(slider, TBM_SETRANGE, FALSE, (LPARAM) MAKELONG(0, 1000));
+  
+    uniformbox = GetDlgItem(m_hwnd, IDC_UNIFORMVAL);  
+
+    if(m_pAppSettings->GetBoolParameter(BP_LM_ADAPTIVE)) {
+      SendMessage(GetDlgItem(m_hwnd, IDC_ADAPTIVE), BM_SETCHECK, BST_CHECKED, 0);
+    }
+    else  {
+      SendMessage(GetDlgItem(m_hwnd, IDC_ADAPTIVE), BM_SETCHECK, BST_UNCHECKED, 0);
+    }
+
+    SendMessage(slider, TBM_SETPOS, TRUE, (LPARAM) m_pAppSettings->GetLongParameter(LP_UNIFORM));
+
+    _sntprintf(m_tcBuffer, 100, TEXT("%0.1f"), m_pAppSettings->GetLongParameter(LP_UNIFORM) / 10.0);
+    SendMessage(uniformbox, WM_SETTEXT, 0, (LPARAM) m_tcBuffer);
+
+  switch(m_pAppSettings->GetLongParameter(LP_LANGUAGE_MODEL_ID)) {
+    case 0:
+      SendMessage(GetDlgItem(m_hwnd, IDC_LM_PPM), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+    case 2:
+      SendMessage(GetDlgItem(m_hwnd, IDC_LM_WORD), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+    case 3:
+      SendMessage(GetDlgItem(m_hwnd, IDC_LM_MIXTURE), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+#ifdef JAPANESE
+    case 4:
+      SendMessage(GetDlgItem(m_hwnd, IDC_LM_JAPANESE), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+#endif
+   }
+ // Populate the orientation selection:
+
+  int iOrientation = m_pAppSettings->GetLongParameter(LP_ORIENTATION);
+
+  if(iOrientation == Dasher::Opts::AlphabetDefault) {
+    SendMessage(GetDlgItem(m_hwnd, IDC_OR_DEFAULT), BM_SETCHECK, BST_CHECKED, 0);
+
+    EnableWindow(GetDlgItem(m_hwnd, IDC_OR_LR), FALSE);
+    EnableWindow(GetDlgItem(m_hwnd, IDC_OR_RL), FALSE);
+    EnableWindow(GetDlgItem(m_hwnd, IDC_OR_TB), FALSE);
+    EnableWindow(GetDlgItem(m_hwnd, IDC_OR_BT), FALSE);
+  }
+  else {
+    SendMessage(GetDlgItem(m_hwnd, IDC_OR_CUSTOM), BM_SETCHECK, BST_CHECKED, 0);
+
+    switch(iOrientation) {
+    case Dasher::Opts::LeftToRight:
+      SendMessage(GetDlgItem(m_hwnd, IDC_OR_LR), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+    case Dasher::Opts::RightToLeft:
+      SendMessage(GetDlgItem(m_hwnd, IDC_OR_RL), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+    case Dasher::Opts::TopToBottom:
+      SendMessage(GetDlgItem(m_hwnd, IDC_OR_TB), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+    case Dasher::Opts::BottomToTop:
+      SendMessage(GetDlgItem(m_hwnd, IDC_OR_BT), BM_SETCHECK, BST_CHECKED, 0);
+      break;
+    }
+  }
+
   HWND ListBox = GetDlgItem(m_hwnd, IDC_ALPHABETS);
   SendMessage(ListBox, LB_RESETCONTENT, 0, 0);
 
@@ -83,28 +153,7 @@ void CAlphabetBox::PopulateList() {
   // Tell list box that we have set an item for it (so that delete and edit can be grayed if required)
   SendMessage(m_hwnd, WM_COMMAND, MAKEWPARAM(IDC_ALPHABETS, LBN_SELCHANGE), 0);
 
-  ListBox = GetDlgItem(m_hwnd, IDC_COLOURS);
-  m_pDasherInterface->GetPermittedValues(SP_COLOUR_ID, ColourList);
 
-  // Add each string to list box and index each one
-  SelectionSet = false;
-  for(unsigned int i = 0; i < ColourList.size(); i++) {
-    Tstring Item;
-    WinUTF8::UTF8string_to_wstring(ColourList[i], Item);
-    LRESULT Index = SendMessage(ListBox, LB_ADDSTRING, 0, (LPARAM) Item.c_str());
-    SendMessage(ListBox, LB_SETITEMDATA, Index, (LPARAM) i);
-    if(ColourList[i] == m_CurrentColours) {
-      SendMessage(ListBox, LB_SETCURSEL, Index, 0);
-      SelectionSet = true;
-    }
-  }
-  if(SelectionSet == false) {
-    SendMessage(ListBox, LB_SETCURSEL, 0, 0);
-    LRESULT CurrentIndex = SendMessage(ListBox, LB_GETITEMDATA, 0, 0);
-    m_CurrentColours = ColourList[CurrentIndex];
-  }
-  // Tell list box that we have set an item for it (so that delete and edit can be grayed if required)
-  SendMessage(m_hwnd, WM_COMMAND, MAKEWPARAM(IDC_COLOURS, LBN_SELCHANGE), 0);
 
 // all the button checkboxes
   for(int ii = 0; ii<sizeof(menutable)/sizeof(menuentry); ii++)
@@ -348,23 +397,43 @@ void CAlphabetBox::PopulateList() {
 //  return true;
 //}
 
-bool CAlphabetBox::Validate() {
-  // Return false if something is wrong to prevent user from clicking to a different page. Please also pop up a dialogue informing the user at this point.
-  return TRUE;
-}
 
 bool CAlphabetBox::Apply() {
 
+  if(SendMessage(GetDlgItem(m_hwnd, IDC_OR_DEFAULT), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_ORIENTATION, Dasher::Opts::AlphabetDefault);
+  else if(SendMessage(GetDlgItem(m_hwnd, IDC_OR_LR), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_ORIENTATION, Dasher::Opts::LeftToRight);
+  else if(SendMessage(GetDlgItem(m_hwnd, IDC_OR_RL), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_ORIENTATION, Dasher::Opts::RightToLeft);
+  else if(SendMessage(GetDlgItem(m_hwnd, IDC_OR_TB), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_ORIENTATION, Dasher::Opts::TopToBottom);
+  else if(SendMessage(GetDlgItem(m_hwnd, IDC_OR_BT), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_ORIENTATION, Dasher::Opts::BottomToTop);
+
+  m_pAppSettings->SetBoolParameter( BP_LM_ADAPTIVE, SendMessage(GetDlgItem(m_hwnd, IDC_ADAPTIVE), BM_GETCHECK, 0, 0)!=0 );
+  
+  double NewUniform;
+  NewUniform = SendMessage(slider, TBM_GETPOS, 0, 0);
+  m_pAppSettings->SetLongParameter( LP_UNIFORM, NewUniform);
+
+  if(SendMessage(GetDlgItem(m_hwnd, IDC_LM_PPM), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_LANGUAGE_MODEL_ID, 0);
+  else if(SendMessage(GetDlgItem(m_hwnd, IDC_LM_WORD), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_LANGUAGE_MODEL_ID, 2);
+  else if(SendMessage(GetDlgItem(m_hwnd, IDC_LM_MIXTURE), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_LANGUAGE_MODEL_ID, 3);
+#ifdef JAPANESE
+  else if(SendMessage(GetDlgItem(m_hwnd, IDC_LM_JAPANESE), BM_GETCHECK, 0, 0))
+    m_pAppSettings->SetLongParameter(LP_LANGUAGE_MODEL_ID, 4);
+#endif
+
+
   if(m_CurrentAlphabet != std::string("")) {
     if(m_CurrentAlphabet != m_pDasherInterface->GetStringParameter(SP_ALPHABET_ID))
       m_pDasherInterface->SetStringParameter(SP_ALPHABET_ID, m_CurrentAlphabet); 
   }
 
-  if(m_CurrentColours != std::string("")) {
-        m_pDasherInterface->SetStringParameter(SP_COLOUR_ID, m_CurrentColours);
-  }
-
-
   for(int ii = 0; ii<sizeof(menutable)/sizeof(menuentry); ii++)
   {
     m_pDasherInterface->SetBoolParameter(menutable[ii].paramNum, 
@@ -378,14 +447,33 @@ bool CAlphabetBox::Apply() {
 
 LRESULT CAlphabetBox::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM lParam) {
   NMHDR *pNMHDR;
+     double NewUniform;
+
+  // most things we pass on to CPrefsPageBase, but we need to handle slider motion
 
   switch (message) {
-  case WM_INITDIALOG:
-    if(!m_hwnd) {               // If this is the initial dialog for the first time
-      m_hwnd = Window;
-      PopulateList();
+  case WM_HSCROLL:
+    if((LOWORD(wParam) == SB_THUMBPOSITION) | (LOWORD(wParam) == SB_THUMBTRACK)) {
+      // Some messages give the new postion
+      NewUniform = HIWORD(wParam);
     }
-    //else if(Editing) {
+    else {
+      // Otherwise we have to ask for it
+      long Pos = SendMessage(slider, TBM_GETPOS, 0, 0);
+      NewUniform = Pos;
+    }
+    {
+      _sntprintf(m_tcBuffer, 100, TEXT("%0.1f"), NewUniform / 10);
+      SendMessage(uniformbox, WM_SETTEXT, 0, (LPARAM) m_tcBuffer);
+    }
+    return TRUE;
+    break;
+  //case WM_INITDIALOG:
+  //  if(!m_hwnd) {               // If this is the initial dialog for the first time
+  //    m_hwnd = Window;
+  //    PopulateList();
+  //  }
+  //  //else if(Editing) {
     //  CustomBox = Window;
     //  InitCustomBox();
     //}
@@ -396,76 +484,76 @@ LRESULT CAlphabetBox::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM l
     //  SendMessage(GetDlgItem(Window, IDC_TEXT), WM_SETTEXT, 0, (LPARAM) (LPCSTR) CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar].Text.c_str());
     //  SendMessage(GetDlgItem(Window, IDC_COLOUR), WM_SETTEXT, 0, (LPARAM) (LPCSTR) colour);
     //}
-    return TRUE;
-    break;
-  case WM_NOTIFY:{
-    pNMHDR = (NMHDR*)lParam;
-    if(m_hPropertySheet==0) {
-      m_hPropertySheet = pNMHDR->hwndFrom;
-    }
-    switch (pNMHDR->code) {
-    case PSN_KILLACTIVE: // About to lose focus
-      SetWindowLong( Window, DWL_MSGRESULT, !Validate());
-      return TRUE;
-      break;
-    case PSN_APPLY: // User clicked OK/Apply - apply the changes
-      if(Apply())
-        SetWindowLong( Window, DWL_MSGRESULT, PSNRET_NOERROR);
-      else
-        SetWindowLong( Window, DWL_MSGRESULT, PSNRET_INVALID);
-      return TRUE;
-      break;
-    //case UDN_DELTAPOS:
-    //  // Moving stuff in here
-    //  if(CurrentInfo.Groups.size() < 1) {
-    //    return TRUE;
-    //    break;
-    //  }
-    //  NMUPDOWN *Data = (NMUPDOWN *) lParam;
-    //  if(Data->hdr.idFrom == IDC_MOVE_GROUP) {
-    //    CAlphIO::AlphInfo::group Tmp = CurrentInfo.Groups[CurrentGroup];
-    //    if(Data->iDelta > 0) {
-    //      if(CurrentGroup + 1 < CurrentInfo.Groups.size()) {
-    //        CurrentInfo.Groups[CurrentGroup] = CurrentInfo.Groups[CurrentGroup + 1];
-    //        CurrentInfo.Groups[CurrentGroup + 1] = Tmp;
-    //        ++CurrentGroup;
-    //      }
-    //    }
-    //    else {
-    //      if(CurrentGroup > 0) {
-    //        CurrentInfo.Groups[CurrentGroup] = CurrentInfo.Groups[CurrentGroup - 1];
-    //        CurrentInfo.Groups[CurrentGroup - 1] = Tmp;
-    //        --CurrentGroup;
-    //      }
-    //    }
-    //    ShowGroups();
-    //  }
-    //  if(Data->hdr.idFrom == IDC_MOVE_CHAR) {
-    //    if(CurrentInfo.Groups[CurrentGroup].Characters.size() < 1) {
-    //      return TRUE;
-    //      break;
-    //    }
-    //    CAlphIO::AlphInfo::character Tmp = CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar];
-    //    if(Data->iDelta > 0) {
-    //      if(CurrentChar + 1 < CurrentInfo.Groups[CurrentGroup].Characters.size()) {
-    //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar] = CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar + 1];
-    //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar + 1] = Tmp;
-    //        ++CurrentChar;
-    //      }
-    //    }
-    //    else {
-    //      if(CurrentChar > 0) {
-    //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar] = CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar - 1];
-    //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar - 1] = Tmp;
-    //        --CurrentChar;
-    //      }
-    //    }
-    //    ShowGroupChars();
-    //  }
-    //  return TRUE;
-    //  break; // End UDN_DELTAPOS
-    }
-  }
+    //return TRUE;
+    //break;
+  //case WM_NOTIFY:{
+  //  pNMHDR = (NMHDR*)lParam;
+  //  if(m_hPropertySheet==0) {
+  //    m_hPropertySheet = pNMHDR->hwndFrom;
+  //  }
+  //  switch (pNMHDR->code) {
+  //  //case PSN_KILLACTIVE: // About to lose focus
+  //  //  SetWindowLong( Window, DWL_MSGRESULT, !Validate());
+  //  //  return TRUE;
+  //  //  break;
+  //  case PSN_APPLY: // User clicked OK/Apply - apply the changes
+  //    if(Apply())
+  //      SetWindowLong( Window, DWL_MSGRESULT, PSNRET_NOERROR);
+  //    else
+  //      SetWindowLong( Window, DWL_MSGRESULT, PSNRET_INVALID);
+  //    return TRUE;
+  //    break;
+  //  //case UDN_DELTAPOS:
+  //  //  // Moving stuff in here
+  //  //  if(CurrentInfo.Groups.size() < 1) {
+  //  //    return TRUE;
+  //  //    break;
+  //  //  }
+  //  //  NMUPDOWN *Data = (NMUPDOWN *) lParam;
+  //  //  if(Data->hdr.idFrom == IDC_MOVE_GROUP) {
+  //  //    CAlphIO::AlphInfo::group Tmp = CurrentInfo.Groups[CurrentGroup];
+  //  //    if(Data->iDelta > 0) {
+  //  //      if(CurrentGroup + 1 < CurrentInfo.Groups.size()) {
+  //  //        CurrentInfo.Groups[CurrentGroup] = CurrentInfo.Groups[CurrentGroup + 1];
+  //  //        CurrentInfo.Groups[CurrentGroup + 1] = Tmp;
+  //  //        ++CurrentGroup;
+  //  //      }
+  //  //    }
+  //  //    else {
+  //  //      if(CurrentGroup > 0) {
+  //  //        CurrentInfo.Groups[CurrentGroup] = CurrentInfo.Groups[CurrentGroup - 1];
+  //  //        CurrentInfo.Groups[CurrentGroup - 1] = Tmp;
+  //  //        --CurrentGroup;
+  //  //      }
+  //  //    }
+  //  //    ShowGroups();
+  //  //  }
+  //  //  if(Data->hdr.idFrom == IDC_MOVE_CHAR) {
+  //  //    if(CurrentInfo.Groups[CurrentGroup].Characters.size() < 1) {
+  //  //      return TRUE;
+  //  //      break;
+  //  //    }
+  //  //    CAlphIO::AlphInfo::character Tmp = CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar];
+  //  //    if(Data->iDelta > 0) {
+  //  //      if(CurrentChar + 1 < CurrentInfo.Groups[CurrentGroup].Characters.size()) {
+  //  //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar] = CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar + 1];
+  //  //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar + 1] = Tmp;
+  //  //        ++CurrentChar;
+  //  //      }
+  //  //    }
+  //  //    else {
+  //  //      if(CurrentChar > 0) {
+  //  //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar] = CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar - 1];
+  //  //        CurrentInfo.Groups[CurrentGroup].Characters[CurrentChar - 1] = Tmp;
+  //  //        --CurrentChar;
+  //  //      }
+  //  //    }
+  //  //    ShowGroupChars();
+  //  //  }
+  //  //  return TRUE;
+  //  //  break; // End UDN_DELTAPOS
+  //  }
+  //}
   case WM_COMMAND:
     
     if(HIWORD(wParam)==BN_CLICKED || HIWORD(wParam)==LBN_SELCHANGE) {
@@ -476,24 +564,24 @@ LRESULT CAlphabetBox::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM l
       }
     }
     switch (LOWORD(wParam)) {
-    case (IDC_DISPLAY):
-      if(HIWORD(wParam) == EN_CHANGE) {
-        HWND Control = GetDlgItem(Window, IDC_DISPLAY);
-        LRESULT BufferLength = SendMessage(Control, WM_GETTEXTLENGTH, 0, 0) + 1;        // +1 to allow for terminator
-        TCHAR *Buffer = new TCHAR[BufferLength];
-        SendMessage(Control, WM_GETTEXT, BufferLength, (LPARAM) Buffer);
-        string ItemName;
-        SendMessage(GetDlgItem(Window, IDC_TEXT), WM_SETTEXT, 0, (LPARAM) Buffer);
-        delete[]Buffer;
-      }
-      break;
+    //case (IDC_DISPLAY):
+    //  if(HIWORD(wParam) == EN_CHANGE) {
+    //    HWND Control = GetDlgItem(Window, IDC_DISPLAY);
+    //    LRESULT BufferLength = SendMessage(Control, WM_GETTEXTLENGTH, 0, 0) + 1;        // +1 to allow for terminator
+    //    TCHAR *Buffer = new TCHAR[BufferLength];
+    //    SendMessage(Control, WM_GETTEXT, BufferLength, (LPARAM) Buffer);
+    //    string ItemName;
+    //    SendMessage(GetDlgItem(Window, IDC_TEXT), WM_SETTEXT, 0, (LPARAM) Buffer);
+    //    delete[]Buffer;
+    //  }
+    //  break;
     case (IDC_ALPHABETS):
       if(HIWORD(wParam) == LBN_SELCHANGE) {
         HWND ListBox = GetDlgItem(m_hwnd, IDC_ALPHABETS);
         LRESULT CurrentItem = SendMessage(ListBox, LB_GETCURSEL, 0, 0);
         LRESULT CurrentIndex = SendMessage(ListBox, LB_GETITEMDATA, CurrentItem, 0);
         m_CurrentAlphabet = AlphabetList[CurrentIndex];
-        CurrentInfo = m_pDasherInterface->GetInfo(m_CurrentAlphabet);
+ /*       CurrentInfo = m_pDasherInterface->GetInfo(m_CurrentAlphabet);
         if(CurrentInfo.Mutable) {
           EnableWindow(GetDlgItem(m_hwnd, IDC_DEL_ALPH), TRUE);
           EnableWindow(GetDlgItem(m_hwnd, IDC_EDIT), TRUE);
@@ -501,19 +589,36 @@ LRESULT CAlphabetBox::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM l
         else {
           EnableWindow(GetDlgItem(m_hwnd, IDC_DEL_ALPH), FALSE);
           EnableWindow(GetDlgItem(m_hwnd, IDC_EDIT), FALSE);
-        }
+        }*/
       }
       return TRUE;
       break;
-      case (IDC_COLOURS):
-      if(HIWORD(wParam) == LBN_SELCHANGE) {
-        HWND ListBox = GetDlgItem(m_hwnd, IDC_COLOURS);
-        LRESULT CurrentItem = SendMessage(ListBox, LB_GETCURSEL, 0, 0);
-        LRESULT CurrentIndex = SendMessage(ListBox, LB_GETITEMDATA, CurrentItem, 0);
-        m_CurrentColours = ColourList[CurrentIndex];
+    case IDC_OR_DEFAULT:
+      if(SendMessage(GetDlgItem(m_hwnd, IDC_OR_DEFAULT), BM_GETCHECK, 0, 0) == BST_CHECKED) {
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_LR), FALSE);
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_RL), FALSE);
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_TB), FALSE);
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_BT), FALSE);
+
+        SendMessage(GetDlgItem(m_hwnd, IDC_OR_LR), BM_SETCHECK, BST_UNCHECKED, 0);
+        SendMessage(GetDlgItem(m_hwnd, IDC_OR_RL), BM_SETCHECK, BST_UNCHECKED, 0);
+        SendMessage(GetDlgItem(m_hwnd, IDC_OR_TB), BM_SETCHECK, BST_UNCHECKED, 0);
+        SendMessage(GetDlgItem(m_hwnd, IDC_OR_BT), BM_SETCHECK, BST_UNCHECKED, 0);
       }
-      return TRUE;
       break;
+    case IDC_OR_CUSTOM:
+      if(SendMessage(GetDlgItem(m_hwnd, IDC_OR_CUSTOM), BM_GETCHECK, 0, 0 == BST_CHECKED)) {
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_LR), TRUE);
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_RL), TRUE);
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_TB), TRUE);
+        EnableWindow(GetDlgItem(m_hwnd, IDC_OR_BT), TRUE);
+
+        // TODO: Should really sort this out, but no way to look up default orientation until 
+        // changes have been applied
+        SendMessage(GetDlgItem(m_hwnd, IDC_OR_LR), BM_SETCHECK, BST_CHECKED, 0);
+      }
+      break;
+     
  /*   case (IDC_GROUPS):
       if(HIWORD(wParam) == LBN_SELCHANGE) {
         HWND GroupList = GetDlgItem(Window, IDC_GROUPS);
@@ -590,16 +695,16 @@ LRESULT CAlphabetBox::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM l
     //    PopulateList();
     //  }
     //  break;
-    case (IDC_DEL_ALPH):{
-        HWND ListBox = GetDlgItem(m_hwnd, IDC_ALPHABETS);
-        LRESULT CurrentItem = SendMessage(ListBox, LB_GETCURSEL, 0, 0);
-        LRESULT CurrentIndex = SendMessage(ListBox, LB_GETITEMDATA, CurrentItem, 0);
-        if(CurrentIndex >= 0 && (unsigned int)CurrentIndex < AlphabetList.size()) {
-          m_pDasherInterface->DeleteAlphabet(AlphabetList[CurrentIndex]);
-          PopulateList();
-        }
-        break;
-      }
+    //case (IDC_DEL_ALPH):{
+    //    HWND ListBox = GetDlgItem(m_hwnd, IDC_ALPHABETS);
+    //    LRESULT CurrentItem = SendMessage(ListBox, LB_GETCURSEL, 0, 0);
+    //    LRESULT CurrentIndex = SendMessage(ListBox, LB_GETITEMDATA, CurrentItem, 0);
+    //    if(CurrentIndex >= 0 && (unsigned int)CurrentIndex < AlphabetList.size()) {
+    //      m_pDasherInterface->DeleteAlphabet(AlphabetList[CurrentIndex]);
+    //      PopulateList();
+    //    }
+    //    break;
+    //  }
     //case (IDC_CLONE):
     //  Cloning = true;
     //  // deliberate fall through
@@ -623,23 +728,27 @@ LRESULT CAlphabetBox::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM l
     //  Editing = true;
     //  DialogBoxParam(WinHelper::hInstApp, (LPCTSTR) IDD_CUSTOMALPHABET, Window, (DLGPROC) WinWrapMap::WndProc, (LPARAM) this);
     //  break;
-    case (IDOK):
-      if(m_CurrentAlphabet != std::string("")) {
-        m_pDasherInterface->SetStringParameter(SP_ALPHABET_ID, m_CurrentAlphabet);
-      }
-      // deliberate fall through
-    case (IDCANCEL):
-      {
-        EndDialog(Window, LOWORD(wParam));
-        return TRUE;
-      }
-    case ID_CUSTOM_CANCEL:
-      PopulateList();           // Need to reget settings for current selection. Cheaty way to do it.
-      EndDialog(Window, LOWORD(wParam));
-      return TRUE;
-      break;
+    //case (IDOK):
+    //  if(m_CurrentAlphabet != std::string("")) {
+    //    m_pDasherInterface->SetStringParameter(SP_ALPHABET_ID, m_CurrentAlphabet);
+    //  }
+    //  // deliberate fall through
+    //case (IDCANCEL):
+    //  {
+    //    EndDialog(Window, LOWORD(wParam));
+    //    return TRUE;
+    //  }
+    //case ID_CUSTOM_CANCEL:
+    //  PopulateList();           // Need to reget settings for current selection. Cheaty way to do it.
+    //  EndDialog(Window, LOWORD(wParam));
+    //  return TRUE;
+    //  break;
     }
   break;
+  default:
+   return CPrefsPageBase::WndProc(Window, message, wParam, lParam);
   }
+
+  // TODO: Sort out return values here
   return FALSE;
 }
