@@ -31,7 +31,9 @@
 #include "FilenameGUI.h"
 #include "../resource.h"
 #include "../../DasherCore/DasherInterfaceBase.h"
+#ifndef _WIN32_WCE
 #include "../ActionSpeech.h"
+#endif
 
 #include "../Common/DasherEncodingToCP.h"
 
@@ -55,16 +57,22 @@ CEdit::CEdit(CAppSettings *pAppSettings) {
   m_pAppSettings = pAppSettings;
 
   CodePage = GetUserCodePage();
+#ifndef _WIN32_WCE
   m_Font = GetCodePageFont(CodePage, 14);
+#endif
 
   // TODO: Generalise this (and don't duplicate - read directly from
   // text buffer).
   speech.resize(0);
 
+#ifndef _WIN32_WCE
   // TODO: Generalise actions, implement those present in Linux
   // version.
   m_pActionSpeech = new CActionSpeech;
   m_pActionSpeech->Activate();
+#else
+  m_pActionSpeech = 0;
+#endif
 
 }
 
@@ -86,8 +94,10 @@ CEdit::~CEdit() {
   if(FileHandle != INVALID_HANDLE_VALUE)
     CloseHandle(FileHandle);
 
+#ifndef _WIN32_WCE
   m_pActionSpeech->Deactivate();
   delete m_pActionSpeech;
+#endif
 }
 
 void CEdit::Move(int x, int y, int Width, int Height) {
@@ -432,74 +442,38 @@ void CEdit::SetFont(string Name, long Size) {
 #else
   // not implemented
 #pragma message ( "CEdit::SetFot not implemented on WinCE")
-  DASHER_ASSERT(0);
+  //DASHER_ASSERT(0);
 #endif
 }
 
 void CEdit::SetInterface(Dasher::CDasherInterfaceBase *DasherInterface) {
   m_pDasherInterface = DasherInterface;
-  
+#ifndef _WIN32_WCE
   // TODO: What on Earth is this doing here?
-  SetFont(m_FontName, m_FontSize);
+  //SetFont(m_FontName, m_FontSize);
+#endif
 }
 
-// void CEdit::write_to_file() {
-//   // TODO: Reimplement if necessary
+std::string CEdit::get_context(int iOffset, int iLength) {
+  TCHAR *wszContent = new TCHAR[iOffset + iLength + 1];
+  
+  SendMessage(WM_GETTEXT, (LONG) (iOffset + iLength + 1), (LONG) wszContent);
 
-//   //const string & TrainFile = m_pDasherInterface->GetTrainFile();
-//   //if(TrainFile == "")
-//   //  return;
-//   //Tstring TTrainFile;
-//   //UTF8string_to_wstring(TrainFile, TTrainFile);
+  std::string strReturn;
+  wstring_to_UTF8string(wszContent + iOffset, strReturn);
 
-//   //HANDLE hFile = CreateFile(TTrainFile.c_str(),
-//   //                          GENERIC_WRITE, 0, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
+  delete[] wszContent;
 
-//   //if(hFile == INVALID_HANDLE_VALUE) {
-//   //  OutputDebugString(TEXT("Can not open file\n"));
-//   //}
-//   //else {
-//   //  DWORD NumberOfBytesWritten;
-//   //  SetFilePointer(hFile, 0, NULL, FILE_END);
-//   //  for(unsigned int i = 0; i < m_Output.size(); i++) {
-//   //    WriteFile(hFile, &m_Output[i], 1, &NumberOfBytesWritten, NULL);
-//   //  }
-
-//   //  m_Output = "";
-//   //  CloseHandle(hFile);
-//   //}
-// }
-
-void CEdit::get_new_context(string &str, int max) {
-  // Currently all of the edit box up to the caret is copied
-  // and then a few characters taken from that.
-  // This is a bit silly, but works for now. IAM 2002/08
-
-  int iStart, iFinish;
-  SendMessage(EM_GETSEL, (LONG) & iStart, (LONG) & iFinish);
-
-  TCHAR *tString = new TCHAR[iFinish + 1];
-
-  SendMessage(WM_GETTEXT, (LONG) (iStart + 1), (LONG) tString);
-
-  string Wasteful;
-  wstring_to_UTF8string(tString, Wasteful);
-
-  if(Wasteful.size() > max)
-    str = Wasteful.substr(Wasteful.size() - max, max);
-  else
-    str = Wasteful;
-
-  delete[]tString;
+  return strReturn;
 }
 
+
 void CEdit::output(const std::string &sText) {
   wstring String;
   WinUTF8::UTF8string_to_wstring(sText, String);
-
   InsertText(String);
 
-  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2) {
+  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == APP_STYLE_DIRECT) {
     const char *DisplayText = sText.c_str();
 #ifdef UNICODE
     if(DisplayText[0] == 0xd && DisplayText[1] == 0xa) {
@@ -552,6 +526,16 @@ void CEdit::output(const std::string &sText) {
 
   UTF8string_to_wstring(sText, newchar);
   speech += newchar;
+
+  // Slightly hacky word by word preview
+  if(newchar == L" ") {
+    if(m_pAppSettings->GetBoolParameter(APP_BP_SPEECH_WORD) && m_pActionSpeech->GetActive())
+      m_pActionSpeech->Preview(m_strCurrentWord);
+    m_strCurrentWord = L"";
+  } 
+  else {
+    m_strCurrentWord += newchar;
+  }
 }
 
 void CEdit::Move(int iDirection, int iDist) {
@@ -585,6 +569,8 @@ void CEdit::Move(int iDirection, int iDist) {
     case EDIT_WORD:
       // Hmm... words are hard - this is a rough and ready approximation:
 
+#ifndef _WIN32_WCE
+      // TODO: Fix this on Windows CE
       iNumChars = SendMessage(WM_GETTEXTLENGTH, 0, 0);
       hMemHandle = (HLOCAL)SendMessage( EM_GETHANDLE, 0, 0);
       strBufferText = std::wstring((WCHAR*)LocalLock(hMemHandle), iNumChars);
@@ -596,6 +582,7 @@ void CEdit::Move(int iDirection, int iDist) {
       else
         iEnd = iEnd + 1;
       iStart = iEnd;
+#endif
       break;
     case EDIT_LINE:
 /*      iEndLine = SendMessage( EM_LINEFROMCHAR, (WPARAM)iEnd, 0);
@@ -639,6 +626,8 @@ void CEdit::Move(int iDirection, int iDist) {
       iEnd = iStart;
       break;
     case EDIT_WORD:
+#ifndef _WIN32_WCE
+      // TODO: Fix this on Windows CE
       iNumChars = SendMessage(WM_GETTEXTLENGTH, 0, 0);
       hMemHandle = (HLOCAL)SendMessage(EM_GETHANDLE, 0, 0);
       strBufferText = std::wstring((WCHAR*)LocalLock(hMemHandle), iNumChars);
@@ -652,6 +641,7 @@ void CEdit::Move(int iDirection, int iDist) {
           iEnd = iEnd + 1;
       }
       iStart = iEnd;
+#endif
       break;
     case EDIT_LINE:
 /*
@@ -711,6 +701,8 @@ void CEdit::Delete(int iDirection, int iDist) {
       ++iEnd;
       break;
     case EDIT_WORD:
+#ifndef _WIN32_WCE
+      // TODO: Fix in Windows CE
       iNumChars = SendMessage(WM_GETTEXTLENGTH, 0, 0);
       hMemHandle = (HLOCAL)SendMessage(EM_GETHANDLE, 0, 0);
       strBufferText = std::wstring((WCHAR*)LocalLock(hMemHandle), iNumChars);
@@ -719,6 +711,7 @@ void CEdit::Delete(int iDirection, int iDist) {
       iEnd = strBufferText.find(' ', iEnd+1);
       if(iEnd == -1)
         iEnd = iNumChars + 1;
+#endif
       break;
     case EDIT_LINE:
 /*
@@ -752,6 +745,7 @@ void CEdit::Delete(int iDirection, int iDist) {
       --iEnd;
       break;
     case EDIT_WORD:
+#ifndef _WIN32_WCE
       iNumChars = SendMessage(WM_GETTEXTLENGTH, 0, 0);
       hMemHandle = (HLOCAL)SendMessage(EM_GETHANDLE, 0, 0);
       strBufferText = std::wstring((WCHAR*)LocalLock(hMemHandle), iNumChars);
@@ -764,6 +758,7 @@ void CEdit::Delete(int iDirection, int iDist) {
         else
           iEnd = iEnd + 1;
       }
+#endif
       break;
     case EDIT_LINE:
 /*       iEndLine = SendMessage(EM_LINEFROMCHAR, (WPARAM)iEnd, 0);
@@ -897,7 +892,7 @@ void CEdit::deletetext(const std::string &sText) {
   // a single symbol
 
 //  if(targetwindow != NULL && textentry == true) {
-if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2) {
+if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == APP_STYLE_DIRECT) {
 
 #ifdef _UNICODE
     fakekey[0].type = fakekey[1].type = INPUT_KEYBOARD;
@@ -919,6 +914,11 @@ if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2) {
     speech.resize(speech.length() - iLength);
   }
 
+  // Shorten the speech buffer (?)
+  if(m_strCurrentWord.length() >= iLength) {
+    m_strCurrentWord.resize(m_strCurrentWord.length() - iLength);
+  }
+
   // And the output buffer (?)
   if(m_Output.length() >= iLength) {
     m_Output.resize(m_Output.length() - iLength);
@@ -932,7 +932,7 @@ void CEdit::speak(int what) {
   // TODO: The remainder of this function is somewhat horrible and hacky...
   
   // TODO: Horrible hack - don't speak in direct entry mode
-  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2)
+  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == APP_STYLE_DIRECT)
     return;
 
   std::wstring strSpeech;
@@ -955,7 +955,7 @@ void CEdit::speak(int what) {
     strSpeech = lastspeech;
   }
 
-  m_pActionSpeech->Execue(strSpeech);
+  m_pActionSpeech->Execute(strSpeech);
 }
 
 void CEdit::SetNewWithDate(bool bNewWithDate) {
@@ -974,6 +974,10 @@ void CEdit::HandleEvent(Dasher::CEvent *pEvent) {
   case EV_STOP:
     HandleStop();
     break;
+  case EV_EDIT_CONTEXT:
+    // TODO: Make this return the context properly. cf Linux 
+    //m_pDasherInterface->SetContext("");
+    break;
   }
 }
 
