@@ -1,4 +1,6 @@
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #ifdef GNOME_LIBS
 #include <glib/gi18n.h>
 #endif
@@ -31,7 +33,6 @@
 #ifdef GNOME_LIBS
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
-#include <libgnomevfs/gnome-vfs.h>
 #endif
 
 // #include <libintl.h>
@@ -184,7 +185,7 @@ int main(int argc, char *argv[]) {
     //   {"preferences", 'p', 0, G_OPTION_ARG_NONE, &preferences, "Show preferences window only", NULL},
     //   {"textentry", 'o', 0, G_OPTION_ARG_NONE, &textentry, "Onscreen text entry mode", NULL},
     //   {"pipe", 's', 0, G_OPTION_ARG_NONE, &stdoutpipe, "Pipe text to stdout", NULL},
-    // Note to translators: This is the help string for "--appstyle"
+    /* Note to translators: This is the help string for "--appstyle". The four options in brackets MUST either NOT be translated or at least it MUST be clear that they must be used in english. Otherwise a user running a non-english system will receive an error message when using the translated one instead of the english one and has no chance to find out the correct option. */
     {"appstyle", 'a', 0, G_OPTION_ARG_STRING, &(sCommandLine.szAppStyle), N_("Application style (traditional, direct, compose or fullscreen)"), "traditional"},
     // Note to translators: This is the help string for "--options"
     {"options", 'o', 0, G_OPTION_ARG_STRING, &(sCommandLine.szOptions), N_("Override stored options"), NULL},
@@ -237,9 +238,7 @@ int main(int argc, char *argv[]) {
      argc, argv,
      GNOME_PARAM_NONE);
 #endif
-
-  gnome_vfs_init();
-#endif
+#endif /* GNOME_LIBS */
 
 #if (defined GNOME_SPEECH || defined GNOME_A11Y)
   if(!bonobo_is_initialized()) {
@@ -284,10 +283,6 @@ void clean_up() {
   /* TODO: check that this really does the right thing with the references counting */
   if(g_pDasherMain)
     g_object_unref(G_OBJECT(g_pDasherMain));
-
-#ifdef GNOME_LIBS
-  gnome_vfs_shutdown();
-#endif
 }
 
 void sigint_handler(int iSigNum) { 
